from boltiot.urls import url
import requests

def request_from(url, *kwargs):
    try:
        response = str(requests.get(url.format(*kwargs)).text)
        return response
    except requests.exceptions.ConnectionError as err:
        return {"success":"0", "message":"A Connection error occurred"}
    except requests.exceptions.Timeout as err:
        return {"success":"0", "message":"The request timed out"}
    except requests.exceptions.TooManyRedirects as err :
        return {"success":"0", "message":"Too many redirects"}
    except requests.exceptions.RequestException as err:
        return {"success":"0", "message":"Not able to handle error"}
    except err:
        return {"success":"0", "message":"Something went wrong"}


def request_test(function):
    result = function
    return result



from bolt import Bolt

#Creating all test cases

#Creating a client
client = Bolt('768d64d5-05b2-463b-95bc-98eedfc5abe7', 'BOLT3432361')

#Testing digitalWrite
result = client.digitalWrite('0','HIGH')

#Testing digitalRead
#result = client.digitalRead('0')

#Testing analogWrite
#result = client.analogWrite('A0','127')

#Testing analogRead
#result = client.analogRead('A0')

#Testing UART commands

#result = client.serialBegin('9600')
#result = client.serialRead('12')
#result = client.serialWrite('hello')

#Version check
#result = client.version()

#Device Restart
#result = client.restart()

#Device status
#result = client.isAlive()

print(result)



from setuptools import setup

setup(
    name = 'boltiot',
    packages = ['boltiot'],
    version = 1.3, #Specify a version here
    description = 'A Python module for communicating with the Bolt Cloud API.', #Add a description here
    author = 'Inventrom Pvt. Ltd.', #Enter an author for the package
    author_email  = 'support@boltiot.com', #Author's Email
    url = 'https://github.com/Inventrom/bolt-api-python', #URL for github repository
    download = 'https://github.com/Inventrom/bolt-api-python/archive/1.8.tar.gz', #Download URL for github repository. Look at instructions...txt file for this part
    keywords = ['iot-platform','bolt','bolt-python'], #Add keywords
    classifiers = [],
    install_requires=[
          'requests',
          'twilio'
      ],
)
